@@ -51,12 +51,12 @@ use warnings;
 use strict;
 
 use Carp qw(croak);
-use Lexical::Var 0.003 ();
-use Module::Runtime 0.007 qw($module_name_rx require_module);
+use Lexical::Var 0.006 ();
+use Module::Runtime 0.011 qw($module_name_rx require_module);
 use Params::Classify 0.000 qw(is_string is_ref);
 use version 0.81 ();
 
-our $VERSION = "0.001";
+our $VERSION = "0.002";
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -76,13 +76,6 @@ functions and other items to the package from which its C<import> method
 was called.  Whatever scalars, arrays, hashes, and subroutines it thus
 exported are added to the lexical environment that is currently compiling.
 
-Optionally, I<MODULE_NAME> may be suffixed with a version number,
-separated from the module name by a "C<->".  The version number must
-conform to the "strict" syntax (see L<version::Internals>).  If this
-is done, then after loading the module it will be checked that what was
-loaded is at least the specified version.  For example, "C<Fcntl-1.01>"
-requests the C<Fcntl> module, version 1.01 or later.
-
 The overall effect, when this is performed at compile time (usually via
 C<use>), is that a C<use> is performed on the I<MODULE_NAME> and I<ARGS>,
 with all of the module's package-based exporting being turned into
@@ -91,6 +84,24 @@ of its own, that will still work correctly when done by this indirect
 mechanism, but there is no point to the indirection if the exporting
 module uses lexical exporting exclusively.
 
+Optionally, I<MODULE_NAME> may be suffixed with a version number,
+separated from the module name by a "C<->".  The version number must
+conform to the "strict" syntax (see L<version::Internals>).  If this
+is done, then after loading the module it will be checked that what was
+loaded is at least the specified version.  For example, "C<Fcntl-1.01>"
+requests the C<Fcntl> module, version 1.01 or later.  This check is
+actually performed by calling the C<VERSION> method of the module, so the
+module can redefine it to have effects other than version checking, which
+some modules do even though it shows poor taste.  Any items exported by
+C<VERSION> into the calling package will be picked up and added to the
+lexical environment, just as if they had been exported by C<import>.
+
+Optionally, I<MODULE_NAME> may be prefixed with a "C<->", in which
+case the module's C<unimport> method is called instead of C<import>.
+This effectively performs a C<no> instead of a C<use>.  This is meant
+to handle the few modules which, in poor taste, switch the conventional
+meanings of C<use> and C<no>.
+
 =item Lexical::Import->import(IMPORT_LIST, ...)
 
 There must be one or more I<IMPORT_LIST>, each of which is a reference
@@ -116,21 +127,31 @@ sub import {
 			unless is_ref($arglist, "ARRAY");
 		croak "$class needs the name of a module to import from"
 			unless is_string($arglist->[0]);
-		my($mname, $reqver) =
+		my($no, $mname, $reqver) =
 			($arglist->[0] =~
-			 /\A($module_name_rx)(?:-($version::STRICT))?\z/o);
+			 /\A(-)?($module_name_rx)(?:-($version::STRICT))?\z/o);
 		croak "malformed module name `@{[$arglist->[0]]}'"
 			unless defined $mname;
 		require_module($mname);
-		$mname->VERSION($reqver) if defined $reqver;
 		my $stagename = "__STAGE".($next_stagenum++);
 		my $stagepkg = "Lexical::Import::".$stagename;
 		my $cleanup_stage = bless({name=>$stagename},
 					"Lexical::Import::__DELETE_STAGE");
 		no strict "refs";
 		%{$stagepkg."::"} = ();
-		eval("package $stagepkg; sub { \"$mname\"->import(\@_) }")
-			->(@{$arglist}[1..$#$arglist]);
+		eval(qq{
+			package $stagepkg;
+			sub {
+				my \$mname = shift;
+				my \$reqver = shift;
+				my \$import = shift;
+				\$mname->VERSION(\$reqver) if defined \$reqver;
+				\$mname->\$import(\@_);
+			}
+		})->(
+			$mname, $reqver, $no ? "unimport" : "import",
+			@{$arglist}[1..$#$arglist],
+		);
 		my @imports;
 		foreach my $name (keys %{$stagepkg."::"}) {
 			next unless $name =~ /\A[A-Z_a-z][0-9A-Z_a-z]*\z/;
@@ -178,6 +199,17 @@ it is liable to bring the variable into existence (with an empty value),
 which looks like it exported the variable, so the empty variable will
 be lexically imported by the real caller.
 
+Subroutine calls, to lexically-imported subroutines, that have neither
+sigil nor parentheses (around the argument list) are subject to an
+ambiguity with indirect object syntax.  If the first argument expression
+begins with a bareword or a scalar variable reference then the Perl
+parser is liable to interpret the call as an indirect method call.
+Normally this syntax would be interpreted as a subroutine call if the
+subroutine exists, but the parser doesn't look at lexically-defined
+subroutines for this purpose.  The call interpretation can be forced by
+prefixing the first argument expression with a C<+>, or by wrapping the
+whole argument list in parentheses.
+
 If this package's C<import> method is called from inside a string
 C<eval> inside a C<BEGIN> block, it does not have proper access to the
 compiling environment, and will complain that it is being invoked outside
@@ -189,7 +221,8 @@ future version.
 
 =head1 SEE ALSO
 
-L<Lexical::Var>
+L<Lexical::Var>,
+L<Sub::Import>
 
 =head1 AUTHOR
 
@@ -197,7 +230,7 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2010 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2010, 2011 Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
